==> zio-aws-machinelearning_2.12-5.17.129.2-sources.jar: zio/aws/machinelearning/model/DescribeDataSourcesResponse.scala <==
package zio.aws.machinelearning.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.machinelearning.model.primitives.StringType
import scala.jdk.CollectionConverters._
final case class DescribeDataSourcesResponse(
    results: Option[Iterable[zio.aws.machinelearning.model.DataSource]] = None,
    nextToken: Option[StringType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.machinelearning.model.DescribeDataSourcesResponse = {
    import DescribeDataSourcesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.machinelearning.model.DescribeDataSourcesResponse
      .builder()
      .optionallyWith(
        results.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.results)
      .optionallyWith(
        nextToken.map(value => StringType.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.machinelearning.model.DescribeDataSourcesResponse.ReadOnly =
    zio.aws.machinelearning.model.DescribeDataSourcesResponse
      .wrap(buildAwsValue())
}
object DescribeDataSourcesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.machinelearning.model.DescribeDataSourcesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.machinelearning.model.DescribeDataSourcesResponse =
      zio.aws.machinelearning.model.DescribeDataSourcesResponse(
        results.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def results: Option[List[zio.aws.machinelearning.model.DataSource.ReadOnly]]
    def nextToken: Option[StringType]
    def getResults: ZIO[Any, AwsError, List[
      zio.aws.machinelearning.model.DataSource.ReadOnly
    ]] = AwsError.unwrapOptionField("results", results)
    def getNextToken: ZIO[Any, AwsError, StringType] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.machinelearning.model.DescribeDataSourcesResponse
  ) extends zio.aws.machinelearning.model.DescribeDataSourcesResponse.ReadOnly {
    override val results
        : Option[List[zio.aws.machinelearning.model.DataSource.ReadOnly]] =
      scala
        .Option(impl.results())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.machinelearning.model.DataSource.wrap(item)
          }.toList
        )
    override val nextToken: Option[StringType] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.machinelearning.model.primitives.StringType(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.machinelearning.model.DescribeDataSourcesResponse
  ): zio.aws.machinelearning.model.DescribeDataSourcesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-machinelearning_2.13-5.17.153.2-sources.jar: zio/aws/machinelearning/model/DescribeDataSourcesResponse.scala <==
package zio.aws.machinelearning.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.machinelearning.model.primitives.StringType
import scala.jdk.CollectionConverters._
final case class DescribeDataSourcesResponse(
    results: Option[Iterable[zio.aws.machinelearning.model.DataSource]] = None,
    nextToken: Option[StringType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.machinelearning.model.DescribeDataSourcesResponse = {
    import DescribeDataSourcesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.machinelearning.model.DescribeDataSourcesResponse
      .builder()
      .optionallyWith(
        results.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.results)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.machinelearning.model.DescribeDataSourcesResponse.ReadOnly =
    zio.aws.machinelearning.model.DescribeDataSourcesResponse
      .wrap(buildAwsValue())
}
object DescribeDataSourcesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.machinelearning.model.DescribeDataSourcesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.machinelearning.model.DescribeDataSourcesResponse =
      zio.aws.machinelearning.model.DescribeDataSourcesResponse(
        results.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def results: Option[List[zio.aws.machinelearning.model.DataSource.ReadOnly]]
    def nextToken: Option[StringType]
    def getResults: ZIO[Any, AwsError, List[
      zio.aws.machinelearning.model.DataSource.ReadOnly
    ]] = AwsError.unwrapOptionField("results", results)
    def getNextToken: ZIO[Any, AwsError, StringType] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.machinelearning.model.DescribeDataSourcesResponse
  ) extends zio.aws.machinelearning.model.DescribeDataSourcesResponse.ReadOnly {
    override val results
        : Option[List[zio.aws.machinelearning.model.DataSource.ReadOnly]] =
      scala
        .Option(impl.results())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.machinelearning.model.DataSource.wrap(item)
          }.toList
        )
    override val nextToken: Option[StringType] =
      scala.Option(impl.nextToken()).map(value => value: StringType)
  }
  def wrap(
      impl: software.amazon.awssdk.services.machinelearning.model.DescribeDataSourcesResponse
  ): zio.aws.machinelearning.model.DescribeDataSourcesResponse.ReadOnly =
    new Wrapper(impl)
}
